==> mingw-w64-clang-aarch64-paraview-5.13.3-1-any.pkg.tar.zst: clangarm64/lib/cmake/paraview/ParaViewClients-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ParaView::Catalyst" for configuration "Release"
set_property(TARGET ParaView::Catalyst APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ParaView::Catalyst PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libvtkPVCatalyst-pv5.13.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::RemotingApplication;VTK::FiltersGeneral;VTK::FiltersHybrid;VTK::vtksys"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libvtkPVCatalyst-pv5.13.dll"
  )

list(APPEND _cmake_import_check_targets ParaView::Catalyst )
list(APPEND _cmake_import_check_files_for_ParaView::Catalyst "${_IMPORT_PREFIX}/lib/libvtkPVCatalyst-pv5.13.dll.a" "${_IMPORT_PREFIX}/bin/libvtkPVCatalyst-pv5.13.dll" )

# Import target "ParaView::PythonCatalyst" for configuration "Release"
set_property(TARGET ParaView::PythonCatalyst APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ParaView::PythonCatalyst PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libvtkPVPythonCatalyst-pv5.13.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::PythonInitializer;ParaView::RemotingServerManager;ParaView::VTKExtensionsCore;VTK::ParallelCore;VTK::WrappingPythonCore;ParaView::RemotingLive"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libvtkPVPythonCatalyst-pv5.13.dll"
  )

list(APPEND _cmake_import_check_targets ParaView::PythonCatalyst )
list(APPEND _cmake_import_check_files_for_ParaView::PythonCatalyst "${_IMPORT_PREFIX}/lib/libvtkPVPythonCatalyst-pv5.13.dll.a" "${_IMPORT_PREFIX}/bin/libvtkPVPythonCatalyst-pv5.13.dll" )

# Import target "ParaView::InSitu" for configuration "Release"
set_property(TARGET ParaView::InSitu APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ParaView::InSitu PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libvtkPVInSitu-pv5.13.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::Catalyst;ParaView::RemotingApplication;ParaView::RemotingLive;ParaView::VTKExtensionsCore;ParaView::PythonCatalyst;ParaView::PythonInitializer;VTK::WrappingPythonCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libvtkPVInSitu-pv5.13.dll"
  )

list(APPEND _cmake_import_check_targets ParaView::InSitu )
list(APPEND _cmake_import_check_files_for_ParaView::InSitu "${_IMPORT_PREFIX}/lib/libvtkPVInSitu-pv5.13.dll.a" "${_IMPORT_PREFIX}/bin/libvtkPVInSitu-pv5.13.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-paraview-6.0.0-1-any.pkg.tar.zst: clangarm64/lib/cmake/paraview/ParaViewClients-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ParaView::Catalyst" for configuration "Release"
set_property(TARGET ParaView::Catalyst APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ParaView::Catalyst PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libvtkPVCatalyst.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::RemotingApplication;VTK::FiltersGeneral;VTK::FiltersHybrid;VTK::vtksys"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libvtkPVCatalyst.dll"
  )

list(APPEND _cmake_import_check_targets ParaView::Catalyst )
list(APPEND _cmake_import_check_files_for_ParaView::Catalyst "${_IMPORT_PREFIX}/lib/libvtkPVCatalyst.dll.a" "${_IMPORT_PREFIX}/bin/libvtkPVCatalyst.dll" )

# Import target "ParaView::PythonCatalyst" for configuration "Release"
set_property(TARGET ParaView::PythonCatalyst APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ParaView::PythonCatalyst PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libvtkPVPythonCatalyst.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::PythonInitializer;ParaView::RemotingServerManager;ParaView::VTKExtensionsCore;VTK::ParallelCore;VTK::WrappingPythonCore;ParaView::RemotingLive"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libvtkPVPythonCatalyst.dll"
  )

list(APPEND _cmake_import_check_targets ParaView::PythonCatalyst )
list(APPEND _cmake_import_check_files_for_ParaView::PythonCatalyst "${_IMPORT_PREFIX}/lib/libvtkPVPythonCatalyst.dll.a" "${_IMPORT_PREFIX}/bin/libvtkPVPythonCatalyst.dll" )

# Import target "ParaView::InSitu" for configuration "Release"
set_property(TARGET ParaView::InSitu APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ParaView::InSitu PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libvtkPVInSitu.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::Catalyst;ParaView::RemotingApplication;ParaView::RemotingLive;ParaView::VTKExtensionsCore;ParaView::PythonCatalyst;ParaView::PythonInitializer;VTK::WrappingPythonCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libvtkPVInSitu.dll"
  )

list(APPEND _cmake_import_check_targets ParaView::InSitu )
list(APPEND _cmake_import_check_files_for_ParaView::InSitu "${_IMPORT_PREFIX}/lib/libvtkPVInSitu.dll.a" "${_IMPORT_PREFIX}/bin/libvtkPVInSitu.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
